@@ -4,13 +4,11 @@ package SPVM::File::Spec::Instance;
 
 =head1 Name
 
-SPVM::File::Spec::Instance - Portably Perform Operations on File Names
+SPVM::File::Spec::Instance - Object-Oriented File::Spec
 
 =head1 Description
 
-C<SPVM::File::Spec::Instance> is the L<SPVM>'s C<File::Spec::Instance> class.
-
-This module is designed to support operations commonly performed on file specifications
+The File::Spec::Instance class of L<SPVM> is an Object-Oriented L<File::Spec|SPVM::File::Spec> class.
 
 =head1 Usage
 
@@ -121,8 +119,7 @@ Yuki Kimoto C<kimoto.yuki@gmail.com>
 
 =head1 Copyright & License
 
-Copyright 2022-2022 Yuki Kimoto, all rights reserved.
+Copyright (c) 2023 Yuki Kimoto
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+MIT License
 
